# inspired from:

# https://python-packaging-user-guide.readthedocs.org/en/latest/single_source_version/
# https://github.com/pypa/warehouse/blob/master/warehouse/__about__.py

__title__ = 'murmurhash'
__version__ = '1.0.2'
__summary__ = 'Cython bindings for MurmurHash'
__uri__ = 'https://github.com/explosion/murmurhash'
__author__ = 'Matthew Honnibal'
__email__ = 'matt@explosion.ai'
__license__ = 'MIT'
